# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`crypto_policy`](#crypto_policy): Configure the system crypto policy settings
* [`crypto_policy::install`](#crypto_policy--install): Manage the installation of the crypto policy package(s)
* [`crypto_policy::update`](#crypto_policy--update): Helper class for triggering a run of update-crypto-policies

## Classes

### <a name="crypto_policy"></a>`crypto_policy`

Configure the system crypto policy settings

#### Parameters

The following parameters are available in the `crypto_policy` class:

* [`ensure`](#-crypto_policy--ensure)
* [`validate_policy`](#-crypto_policy--validate_policy)
* [`force_fips_override`](#-crypto_policy--force_fips_override)
* [`manage_installation`](#-crypto_policy--manage_installation)

##### <a name="-crypto_policy--ensure"></a>`ensure`

Data type: `Optional[String]`

The system crypto policy that you wish to enforce

* Will be checked against `$facts['simplib__crypto_policy_state']['global_policies_available']` for validity

Default value: `simplib::lookup('simp_options::fips', { 'default_value' => pick($facts['fips_enabled'], false) }) ? { true => 'FIPS', default => undef`

##### <a name="-crypto_policy--validate_policy"></a>`validate_policy`

Data type: `Boolean`

Disables validation of the `$ensure` parameter prior to application

Default value: `true`

##### <a name="-crypto_policy--force_fips_override"></a>`force_fips_override`

Data type: `Boolean`

Set this to indicate that you wish to force the system into the mode
specified by `$ensure` even if the system is in FIPS mode

* WARNING: This may break all crypto on your system

Default value: `false`

##### <a name="-crypto_policy--manage_installation"></a>`manage_installation`

Data type: `Boolean`

Enables management of the system installation via the `crypto_policy::install` class

Default value: `true`

### <a name="crypto_policy--install"></a>`crypto_policy::install`

Manage the installation of the crypto policy package(s)

#### Parameters

The following parameters are available in the `crypto_policy::install` class:

* [`packages`](#-crypto_policy--install--packages)
* [`package_ensure`](#-crypto_policy--install--package_ensure)

##### <a name="-crypto_policy--install--packages"></a>`packages`

Data type: `Array[String[1]]`

The list of packages to manage for this capability

Default value: `['crypto-policies', 'crypto-policies-scripts']`

##### <a name="-crypto_policy--install--package_ensure"></a>`package_ensure`

Data type: `String[1]`

The 'ensure' parameter for `$packages`

* NOTE: There are issues with `crypto-policies < 20190000` which may render
  a FIPS system inaccessible.

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'latest' })`

### <a name="crypto_policy--update"></a>`crypto_policy::update`

This is deliberately not kept private in case other classes need to trigger
an update but do not wish to include full management

#### Parameters

The following parameters are available in the `crypto_policy::update` class:

* [`command`](#-crypto_policy--update--command)

##### <a name="-crypto_policy--update--command"></a>`command`

Data type: `Stdlib::Absolutepath`

The path to the command to be executed

Default value: `'/usr/bin/update-crypto-policies'`

